﻿using AutoWorkshopBusinessLogic.OfficePackage.HelperEnums;
using AutoWorkshopBusinessLogic.OfficePackage.HelperModels;

namespace AutoWorkshopBusinessLogic.OfficePackage
{
    public abstract class AbstractSaveToWord
    {
        public void CreateDoc(WordInfo Info)
        {
            CreateWord(Info);

            CreateParagraph(new WordParagraph
            {
                Texts = new List<(string, WordTextProperties)> { (Info.Title, new WordTextProperties { Bold = true, Size = "24", }) },
                TextProperties = new WordTextProperties
                {
                    Size = "24",
                    JustificationType = WordJustificationType.Center
                }
            });

            foreach (var Repair in Info.Repairs)
            {
                CreateParagraph(new WordParagraph
                {
                    Texts = new List<(string, WordTextProperties)> {
                        (Repair.RepairName, new WordTextProperties { Size = "24", Bold = true}),
                        ("\t"+Repair.Price.ToString(), new WordTextProperties{Size = "24"})
                    },
                    TextProperties = new WordTextProperties
                    {
                        Size = "24",
                        JustificationType = WordJustificationType.Both
                    }
                });
            }

            SaveWord(Info);
        }
        
        protected abstract void CreateWord(WordInfo Info);
        
        protected abstract void CreateParagraph(WordParagraph Paragraph);
        
        protected abstract void SaveWord(WordInfo Info);
    }
}
