﻿using AutoWorkshopContracts.BindingModels;
using AutoWorkshopContracts.SearchModels;
using AutoWorkshopContracts.StoragesContracts;
using AutoWorkshopContracts.ViewModels;
using AutoWorkshopFileImplement.Models;

namespace AutoWorkshopFileImplement.Implements
{
    public class ImplementerStorage : IImplementerStorage
    {
        private readonly DataFileSingleton _source;
        
        public ImplementerStorage()
        {
            _source = DataFileSingleton.GetInstance();
        }

        public List<ImplementerViewModel> GetFullList()
        {
            return _source.Implementers.Select(x => x.GetViewModel).ToList();
        }

        public List<ImplementerViewModel> GetFilteredList(ImplementerSearchModel Model)
        {
            if (Model == null)
                return new();

            if (Model.Id.HasValue)
            {
                var Res = GetElement(Model);
                return Res != null ? new() { Res } : new();
            }
            
            if (Model.ImplementerFIO != null)
            {
                return _source.Implementers
                    .Where(x => x.ImplementerFIO.Equals(Model.ImplementerFIO))
                    .Select(x => x.GetViewModel)
                    .ToList();
            }
            
            return new();
        }

        public ImplementerViewModel? GetElement(ImplementerSearchModel Model)
        {
            if (Model.Id.HasValue)
                return _source.Implementers.FirstOrDefault(x => x.Id == Model.Id)?.GetViewModel;

            if (Model.ImplementerFIO != null && Model.Password != null)
                return _source.Implementers.FirstOrDefault(x => x.ImplementerFIO.Equals(Model.ImplementerFIO) && x.Password.Equals(Model.Password))?.GetViewModel;

            if (Model.ImplementerFIO != null)
                return _source.Implementers.FirstOrDefault(x => x.ImplementerFIO.Equals(Model.ImplementerFIO))?.GetViewModel;

            return null;
        }

        public ImplementerViewModel? Insert(ImplementerBindingModel Model)
        {
            Model.Id = _source.Implementers.Count > 0 ? _source.Implementers.Max(x => x.Id) + 1 : 1;
 
            var Res = Implementer.Create(Model);
            if (Res != null)
            {
                _source.Implementers.Add(Res);
                _source.SaveImplementers();
            }
            
            return Res?.GetViewModel;
        }

        public ImplementerViewModel? Update(ImplementerBindingModel Model)
        {
            var Res = _source.Implementers.FirstOrDefault(x => x.Id == Model.Id);            
            if (Res != null)
            {
                Res.Update(Model);
                _source.SaveImplementers();
            }
            
            return Res?.GetViewModel;
        }

        public ImplementerViewModel? Delete(ImplementerBindingModel Model)
        {
            var Res = _source.Implementers.FirstOrDefault(x => x.Id == Model.Id);
            if (Res != null)
            {
                _source.Implementers.Remove(Res);
                _source.SaveImplementers();
            }
            
            return Res?.GetViewModel;
        }
    }
}
