﻿using AutoWorkshopContracts.BindingModels;
using AutoWorkshopContracts.SearchModels;
using AutoWorkshopContracts.StoragesContracts;
using AutoWorkshopContracts.ViewModels;
using AutoWorkshopFileImplement.Models;

namespace AutoWorkshopFileImplement.Implements
{
	public class MessageInfoStorage : IMessageInfoStorage
	{
		private readonly DataFileSingleton _source;

		public MessageInfoStorage()
		{
			_source = DataFileSingleton.GetInstance();
		}

		public List<MessageInfoViewModel> GetFullList()
		{
			return _source.Messages
				.Select(x => x.GetViewModel)
				.ToList();
		}

		public List<MessageInfoViewModel> GetFilteredList(MessageInfoSearchModel Model)
		{
			return _source.Messages
				.Where(x => x.ClientId.HasValue && x.ClientId == Model.ClientId)
				.Select(x => x.GetViewModel)
				.ToList();
		}

		public MessageInfoViewModel? GetElement(MessageInfoSearchModel Model)
		{
			if (string.IsNullOrEmpty(Model.MessageId))
				return null;

			return _source.Messages
				.FirstOrDefault(x => x.MessageId == Model.MessageId)?
				.GetViewModel;
		}

		public MessageInfoViewModel? Insert(MessageInfoBindingModel Model)
		{
			var NewMessageInfo = MessageInfo.Create(Model);

			if (NewMessageInfo == null)
				return null;

			_source.Messages.Add(NewMessageInfo);
			_source.SaveMessages();

			return NewMessageInfo.GetViewModel;
		}
	}
}
